@@ -36,6 +36,8 @@ class Configuration(ConfigurationBase):
     stitch_mode = attr.ib(default=StitchMode.Scroll)  # type: StitchMode
     hide_scrollbars = attr.ib(default=False)  # type: bool
     hide_caret = attr.ib(default=False)  # type: bool
+    # Indicates that a mobile simulator is being used
+    is_simulator = attr.ib(default=None)  # type: Optional[bool]
 
     # Rendering Configuration
     _browsers_info = attr.ib(init=False, factory=list)  # type: List[IRenderBrowserInfo]
@@ -43,6 +45,7 @@ class Configuration(ConfigurationBase):
         default=None
     )  # type: Optional[Tuple[VisualGridOption]]
     disable_browser_fetching = attr.ib(default=False)  # type: bool
+    enable_cross_origin_rendering = attr.ib(default=True)  # type: bool
 
     def set_force_full_page_screenshot(self, force_full_page_screenshot):
         # type: (bool) -> Configuration
@@ -83,6 +86,11 @@ class Configuration(ConfigurationBase):
         self.disable_browser_fetching = disable_browser_fetching
         return self
 
+    def set_enable_cross_origin_rendering(self, enable_cross_origin_rendering):
+        # type: (bool) -> Configuration
+        self.enable_cross_origin_rendering = enable_cross_origin_rendering
+        return self
+
     @overload  # noqa
     def add_browser(self, desktop_browser_info):
         # type: (DesktopBrowserInfo) -> Configuration
